sampling
--------
.. automodule:: sampling
  :members:
  :undoc-members:

persistent_uniform_sampling
---------------------------
.. automodule:: persistent_uniform_sampling
  :members:
  :undoc-members:
